![Logo icon](contents/logo/logo.svg "Software-name logo")
# CommonZ
**common for me and maybe for you**


## 🚩 Intro
*Python modules for selecting,grouping,simplifying the common tasks*  


## 📋 Glossary
 - Python  
	is a general-purpose programming language.
 - modules  
	Are files consisting of Python code.
 - common  
	Something occurring often.


## ℹ️ Description
There is already many python modules,  
But i think some are wrong, and should not be used,  
or they have a lot of confusing options.  
Thats the reason for me to write modules wrapping what i need.  
Then instead of looking again and again what should i use and how to use it correctly, i just go into my own modules.  
Also making these modules independent of projects allows to share the upgrades and bug fix more easily.


## 📝 Note
 - The modules are written for Python3 and no effort are made for compatibility with Python2.
 - The modules are only tested on Linux O.S.  hoping to be able to work on other platforms. 


## 📜 History
 - Origin:
	Initiate by [N-z0](mailto:syslog@laposte.net) in 2017


## ❤️ Special thanks
I am very grateful for all those modules that i use in my own modules,  
of course i respect their license, and would like to push these people on top,  
Because without them im not much.  

